register_source

Macro register_source 

macro_rules! register_source {
    ($source_type:ty $(, $param:ident)*) => { ... };
    (@single ListingProvider) => { ... };
    (@single Home) => { ... };
    (@single DynamicListings) => { ... };
    (@single DynamicFilters) => { ... };
    (@single DynamicSettings) => { ... };
    (@single PageImageProcessor) => { ... };
    (@single ImageRequestProvider) => { ... };
    (@single PageDescriptionProvider) => { ... };
    (@single AlternateCoverProvider) => { ... };
    (@single BaseUrlProvider) => { ... };
    (@single NotificationHandler) => { ... };
    (@single DeepLinkHandler) => { ... };
    (@single BasicLoginHandler) => { ... };
    (@single WebLoginHandler) => { ... };
    (@single MigrationHandler) => { ... };
}
Registers a source for use with Aidoku.

The first argument should be the struct that implements the Source trait, and the following arguments should be all the additional traits that the source implements.

Examples

struct TestSource;

impl Source for TestSource { /* ... */ }
impl Home for TestSource { /* ... */ }

// register TestSource with the extra Home trait
register_source!(TestSource, Home);